Step: 1
Step: 2
Step: 3
Step: 4
Step: 5
Step: 6
Step: 7
Step: 8
Step: 9
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),4) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),6) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),7)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),4) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),6)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),4) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),7) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),6)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),4) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),5) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),7)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),4) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),5)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),4) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),7) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),5)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),4) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),5) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),6)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),4) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),6) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),5)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),4) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),6) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),5)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),4) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),5) occurs(cpa_certify(cpa_p2),7) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),6)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),4) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),6) occurs(cpa_certify(cpa_p2),7) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),5)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),4) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),6) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),5)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),5) occurs(cpa_certify(cpa_p0),3) occurs(cpa_certify(cpa_p1),6) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),4) occurs(cpa_obtain(cpa_p2,cpa_s2),7)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),5) occurs(cpa_certify(cpa_p0),3) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),4) occurs(cpa_obtain(cpa_p2,cpa_s2),6)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),5) occurs(cpa_certify(cpa_p0),3) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),7) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),4) occurs(cpa_obtain(cpa_p2,cpa_s2),6)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),5) occurs(cpa_certify(cpa_p0),4) occurs(cpa_certify(cpa_p1),6) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),7)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),5) occurs(cpa_certify(cpa_p0),4) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),6)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),5) occurs(cpa_certify(cpa_p0),4) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),7) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),6)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),5) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),4) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),7)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),5) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),4) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),6)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),5) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),4) occurs(cpa_certify(cpa_p2),7) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),6)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),6) occurs(cpa_certify(cpa_p0),3) occurs(cpa_certify(cpa_p1),5) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),4) occurs(cpa_obtain(cpa_p2,cpa_s2),7)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),6) occurs(cpa_certify(cpa_p0),4) occurs(cpa_certify(cpa_p1),5) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),7)
occurs(cpa_advance(cpa_s0,cpa_s1),2) occurs(cpa_advance(cpa_s1,cpa_s2),6) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),4) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),3) occurs(cpa_obtain(cpa_p2,cpa_s2),7)
occurs(cpa_advance(cpa_s0,cpa_s1),3) occurs(cpa_advance(cpa_s1,cpa_s2),5) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),6) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),4) occurs(cpa_obtain(cpa_p2,cpa_s2),7)
occurs(cpa_advance(cpa_s0,cpa_s1),3) occurs(cpa_advance(cpa_s1,cpa_s2),5) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),4) occurs(cpa_obtain(cpa_p2,cpa_s2),6)
occurs(cpa_advance(cpa_s0,cpa_s1),3) occurs(cpa_advance(cpa_s1,cpa_s2),5) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),7) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),4) occurs(cpa_obtain(cpa_p2,cpa_s2),6)
occurs(cpa_advance(cpa_s0,cpa_s1),3) occurs(cpa_advance(cpa_s1,cpa_s2),6) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),5) occurs(cpa_certify(cpa_p2),8) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p1,cpa_s1),4) occurs(cpa_obtain(cpa_p2,cpa_s2),7)
Step: 10
Step: 11
Step: 12
Step: 13
Step: 14
Step: 15
Step: 16
Step: 17
Step: 18
Step: 19
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),14) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),14) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),14) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),14) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),14) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),14) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),15) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),14) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),15) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),14) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),14) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),14) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),15) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),14) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),10) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),12) occurs(cpa_certify(cpa_p2),15) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),11) occurs(cpa_obtain(cpa_p2,cpa_s2),14) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),13)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),13) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),14) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),15) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),16) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),17) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),10) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p1),10) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p1,cpa_s1),9) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),6) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),7) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),8) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),5) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),9) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),7) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),6) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),8) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),12) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),13) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),14) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),15) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),16) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),11) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),17) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),13) occurs(cpa_certify(cpa_p2),16) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),12) occurs(cpa_obtain(cpa_p2,cpa_s2),15) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),14)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
occurs(cpa_advance(cpa_s0,cpa_s1),6) occurs(cpa_advance(cpa_s1,cpa_s2),12) occurs(cpa_certify(cpa_p0),2) occurs(cpa_certify(cpa_p0),5) occurs(cpa_certify(cpa_p1),11) occurs(cpa_certify(cpa_p1),8) occurs(cpa_certify(cpa_p2),14) occurs(cpa_certify(cpa_p2),17) occurs(cpa_obtain(cpa_p0,cpa_s0),1) occurs(cpa_obtain(cpa_p0,cpa_s0),4) occurs(cpa_obtain(cpa_p1,cpa_s1),10) occurs(cpa_obtain(cpa_p1,cpa_s1),7) occurs(cpa_obtain(cpa_p2,cpa_s2),13) occurs(cpa_obtain(cpa_p2,cpa_s2),16) occurs(cpa_request_copy(cpa_p0,cpa_s0),3) occurs(cpa_request_copy(cpa_p1,cpa_s1),9) occurs(cpa_request_copy(cpa_p2,cpa_s2),15)
SAT
